<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

$config['export_res'] = [
    'resource' => [
        'csv'     => [
            'title'  => 'CSV',
            'method' => 'csv',
        ],
        'outlook' => [
            'title'  => 'Outlook',
            'method' => 'outlook',
        ],
        'gmail'   => [
            'title'  => 'Gmail',
            'method' => 'gmail',
        ],
    ],
    'default'  => 'csv'
];

$config['newsletter_time_point'] = 3;